@@ -28,7 +28,7 @@ headers = {
     'Content-Type':'application/json',
 }
 
-async def get_ShipRank(qqid,info,ev):
+async def get_ShipRank(server_type,info,bot,ev):
     try:
         bot = get_bot()
         if len(info) == 2:
@@ -51,19 +51,19 @@ async def get_ShipRank(qqid,info,ev):
                 for each in shipList:
                     flag += 1
                     msg += f"{flag}：{tiers[each[3]-1]} {each[1]}\n"
-                ShipSecletProcess[qqid] = ShipSlectState(False, None, shipList)
+                ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, shipList)
                 img = await text_to_pic(text=msg,css_path = str(template_path/"text-ship.css"),width=250) 
                 await bot.send(ev,MessageSegment.image(img))
                 a = 0
-                while a < 40 and not ShipSecletProcess[qqid].state:
+                while a < 40 and not ShipSecletProcess[ev.user_id].state:
                     a += 1
                     await asyncio.sleep(0.5)
-                if ShipSecletProcess[qqid].state and ShipSecletProcess[qqid].SlectIndex <= len(shipList):
-                    select_shipId = int(shipList[ShipSecletProcess[qqid].SlectIndex-1][0])
-                    number_url += f"{select_shipId},{shipList[ShipSecletProcess[qqid].SlectIndex-1][2]}"
-                    ShipSecletProcess[qqid] = ShipSlectState(False, None, None)
+                if ShipSecletProcess[ev.user_id].state and ShipSecletProcess[ev.user_id].SlectIndex <= len(shipList):
+                    select_shipId = int(shipList[ShipSecletProcess[ev.user_id].SlectIndex-1][0])
+                    number_url += f"{select_shipId},{shipList[ShipSecletProcess[ev.user_id].SlectIndex-1][2]}"
+                    ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
                 else:
-                    ShipSecletProcess[qqid] = ShipSlectState(False, None, None)
+                    ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
                     return '已超时退出'
         else:
             return '找不到船'
